@@ -23,6 +23,8 @@
 #include <QLayout>
 #include <QTimer>
 
+// TODO: #define KS_CLASSIC
+
 #ifdef KS_DBUS
 	#include <QDBusConnection>
 #endif // KS_DBUS
@@ -40,6 +42,7 @@
 	#include <KStandardAction>
 #endif // KS_PURE_QT
 
+#include "actions/bootentry.h"
 #include "actions/extras.h"
 #include "actions/lock.h"
 #include "actions/test.h"
@@ -188,8 +191,13 @@ bool MainWindow::checkCommandLine() {
 			}
 			
 			// execute action and quit now
-			if (actionToActivate->authorize(0))
+			if (actionToActivate->authorize(0)) {
+				// HACK:
+				if ("test" == actionToActivate->id())
+					actionToActivate->readConfig("KShutdown Action " + actionToActivate->id(), Config::user());
+			
 				actionToActivate->activate(false);
+			}
 			
 			return true;
 		}
@@ -309,7 +317,7 @@ void MainWindow::setTime(const QString &selectTrigger, const QTime &time, const
 
 	setSelectedTrigger(selectTrigger);
 	Trigger *trigger = getSelectedTrigger();
-	DateTimeTriggerBase *dateTimeTrigger = dynamic_cast<DateTimeTriggerBase *>(trigger);
+	auto *dateTimeTrigger = dynamic_cast<DateTimeTriggerBase *>(trigger);
 	
 	// ensure the trigger exists and is valid
 	if (!dateTimeTrigger || (trigger->id() != selectTrigger)) {
@@ -358,6 +366,9 @@ void MainWindow::setActive(const bool yes) {
 	if (m_active == yes)
 		return;
 
+	if (!yes && !PasswordDialog::authorize(this, i18n("Cancel"), "kshutdown/action/cancel"))
+		return;
+
 	Action *action = getSelectedAction();
 	
 	if (yes && !action->isEnabled()) {
@@ -485,13 +496,13 @@ void MainWindow::setTime(const QString &trigger, const QString &time) {
 	setTime(trigger, t, absolute);
 }
 
-void MainWindow::setWaitForProcess(const qlonglong pid) {
+void MainWindow::setWaitForProcess(const qint64 pid) {
 	U_DEBUG << "MainWindow::setWaitForProcess( " << pid << " )" U_END;
 
 	setActive(false);
 
 	setSelectedTrigger("process-monitor");
-	ProcessMonitor *processMonitor = dynamic_cast<ProcessMonitor *>(
+	auto *processMonitor = dynamic_cast<ProcessMonitor *>(
 		getSelectedTrigger()
 	);
 	
@@ -506,11 +517,11 @@ void MainWindow::setWaitForProcess(const qlonglong pid) {
 // protected
 
 void MainWindow::closeEvent(QCloseEvent *e) {
-	writeConfig();
-	
 	// normal close
 	bool hideInTray = Config::minimizeToSystemTrayIcon() && Config::systemTrayIconEnabled();
 	if (!e->spontaneous() || m_forceQuit || Action::totalExit() || !hideInTray) {
+		writeConfig();
+	
 		e->accept();
 
 		// HACK: ?
@@ -721,8 +732,20 @@ void MainWindow::initMenuBar() {
 #endif // KS_NATIVE_KDE
 
 		fileMenu->addAction(confirmAction);
-		if ((id == "reboot") || (id == "suspend"))
+
+		if (id == "reboot") {
+/* TODO: boot menu
+			#ifdef Q_OS_LINUX
+			QStringList bootEntryList = BootEntry::getList();
+			if (!bootEntryList.isEmpty())
+				fileMenu->addMenu(new BootEntryMenu(this));
+			#endif // Q_OS_LINUX
+*/
 			fileMenu->addSeparator();
+		}
+		else if (id == "suspend") {
+			fileMenu->addSeparator();
+		}
 	}
 	fileMenu->addSeparator();
 	fileMenu->addAction(m_cancelAction);
@@ -853,6 +876,13 @@ void MainWindow::initWidgets() {
 	m_cancelAction->setIcon(U_STOCK_ICON("dialog-cancel"));
 #endif // KS_NATIVE_KDE
 	connect(m_cancelAction, SIGNAL(triggered()), SLOT(onCancel()));
+
+	#ifdef KS_CLASSIC
+	QPalette windowPalette;
+	windowPalette.setColor(QPalette::Window, QColor(0xA7DC6B));
+	windowPalette.setColor(QPalette::WindowText, Qt::black);
+	setPalette(windowPalette);
+	#endif // KS_CLASSIC
 }
 
 void MainWindow::pluginConfig(const bool read) {
@@ -934,6 +964,19 @@ void MainWindow::updateWidgets() {
 
 	bool canCancel = !Utils::isRestricted("kshutdown/action/cancel");
 
+	#ifdef KS_CLASSIC
+	QPalette buttonPalette;
+	if (m_active) {
+		buttonPalette.setColor(QPalette::Button, QColor(0xDCD86A));
+		buttonPalette.setColor(QPalette::ButtonText, Qt::black);
+	}
+	else {
+		buttonPalette.setColor(QPalette::Button, QColor(0xDC6A6E));
+		buttonPalette.setColor(QPalette::ButtonText, Qt::white);
+	}
+	m_okCancelButton->setPalette(buttonPalette);
+	#endif // KS_CLASSIC
+
 #ifdef KS_NATIVE_KDE
 	m_okCancelButton->setGuiItem(
 		m_active
@@ -1037,17 +1080,16 @@ void MainWindow::onAbout() {
 #endif // KS_PORTABLE
 
 QString license =
-"This program is free software; you can redistribute it and/or modify<br>" \
-"it under the terms of the GNU General Public License as published by<br>" \
-"the Free Software Foundation; either version 2 of the License, or<br>" \
-"(at your option) any later version.<br>" \
-"<br>" \
-"This program is distributed in the hope that it will be useful,<br>" \
-"but WITHOUT ANY WARRANTY; without even the implied warranty of<br>" \
-"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the<br>" \
-"GNU General Public License for more details.<br>" \
+"This program is <b>free software</b>; you can redistribute it and/or modify\n" \
+"it under the terms of the GNU General Public License as published by\n" \
+"the Free Software Foundation; either version 2 of the License, or\n" \
+"(at your option) any later version.\n" \
+"\n" \
+"This program is distributed in the hope that it will be useful,\n" \
+"but <b>WITHOUT ANY WARRANTY</b>; without even the implied warranty of\n" \
+"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n" \
+"GNU General Public License for more details.\n" \
 "&lt;<a href=\"http://www.gnu.org/licenses/\">http://www.gnu.org/licenses/</a>&gt;";
-license = license.replace(' ', "&nbsp;"); // no wrap
 
 	QMessageBox::about( // krazy:exclude=qclasses
 		this,
@@ -1055,12 +1097,9 @@ license = license.replace(' ', "&nbsp;"); // no wrap
 		"<qt>" \
 		"<h1>KShutdown " + version + "</h1>" +
 		i18n("A graphical shutdown utility") + "<br>" \
-		"<br>" \
 		KS_COPYRIGHT "<br>" \
-		"<br>" \
 		"<a href=\"" KS_HOME_PAGE "\">" KS_HOME_PAGE "</a><br>" \
-		"<br>" +
-		license +
+		"<pre>" + license + "</pre>" +
 		"</qt>"
 	);
 }
@@ -1096,9 +1135,6 @@ void MainWindow::onActionActivated(int index) {
 }
 
 void MainWindow::onCancel() {
-	if (!PasswordDialog::authorize(this, i18n("Cancel"), "kshutdown/action/cancel"))//!!!
-		return;
-
 	setActive(false);
 }
 
@@ -1132,14 +1168,14 @@ void MainWindow::onCheckTrigger() {
 
 #ifdef KS_NATIVE_KDE
 void MainWindow::onConfigureNotifications() {
-	if (!PasswordDialog::authorize(this, i18n("Preferences"), "action/options_configure_notifications"))
+	if (!PasswordDialog::authorizeSettings(this))
 		return;
 
 	KNotifyConfigWidget::configure(this);
 }
 
 void MainWindow::onConfigureShortcuts() {
-	if (!PasswordDialog::authorize(this, i18n("Preferences"), "action/options_configure_keybinding"))
+	if (!PasswordDialog::authorizeSettings(this))
 		return;
 
 	KShortcutsDialog dialog(KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsDisallowed, this);
@@ -1168,13 +1204,10 @@ void MainWindow::onForceClick() {
 
 void MainWindow::onOKCancel() {
 	U_DEBUG << "MainWindow::onOKCancel()" U_END;
-
-	if (m_active && !PasswordDialog::authorize(this, i18n("Cancel"), "kshutdown/action/cancel"))//!!!cli
-		return;
 	
 	// show error message if selected date/time is invalid
 	if (!m_active) {
-		DateTimeTrigger *dateTimeTrigger = dynamic_cast<DateTimeTrigger *>(getSelectedTrigger());
+		auto *dateTimeTrigger = dynamic_cast<DateTimeTrigger *>(getSelectedTrigger());
 		if (
 			dateTimeTrigger &&
 			(dateTimeTrigger->dateTime() <= QDateTime::currentDateTime())
@@ -1191,7 +1224,7 @@ void MainWindow::onOKCancel() {
 void MainWindow::onPreferences() {
 	U_DEBUG << "MainWindow::onPreferences()" U_END;
 	
-	if (!PasswordDialog::authorize(this, i18n("Preferences"), "action/options_configure"))
+	if (!PasswordDialog::authorizeSettings(this))
 		return;
 
 	// DOC: http://www.kdedevelopers.org/node/3919
